@@ -78,6 +78,7 @@ INSTALLED_APPS = (
     'allauth.socialaccount.providers.dropbox',
     'allauth.socialaccount.providers.dwolla',
     'allauth.socialaccount.providers.edmodo',
+    'allauth.socialaccount.providers.edx',
     'allauth.socialaccount.providers.eveonline',
     'allauth.socialaccount.providers.evernote',
     'allauth.socialaccount.providers.eventbrite',
@@ -96,6 +97,7 @@ INSTALLED_APPS = (
     'allauth.socialaccount.providers.instagram',
     'allauth.socialaccount.providers.jupyterhub',
     'allauth.socialaccount.providers.kakao',
+    'allauth.socialaccount.providers.keycloak',
     'allauth.socialaccount.providers.line',
     'allauth.socialaccount.providers.linkedin',
     'allauth.socialaccount.providers.linkedin_oauth2',
@@ -103,6 +105,7 @@ INSTALLED_APPS = (
     'allauth.socialaccount.providers.mailru',
     'allauth.socialaccount.providers.meetup',
     'allauth.socialaccount.providers.microsoft',
+    'allauth.socialaccount.providers.mixer',
     'allauth.socialaccount.providers.naver',
     'allauth.socialaccount.providers.nextcloud',
     'allauth.socialaccount.providers.odnoklassniki',
@@ -141,6 +144,7 @@ INSTALLED_APPS = (
     'allauth.socialaccount.providers.windowslive',
     'allauth.socialaccount.providers.xing',
     'allauth.socialaccount.providers.yahoo',
+    'allauth.socialaccount.providers.yandex',
     'allauth.socialaccount.providers.ynab',
 )
 
